@@ -98,7 +98,7 @@ class ManageFiles():
                 with requests.post(url, file, headers=headers, stream=True) as req:
                     for i in req.iter_lines():
                         response += str(i)
-            response = json.loads(req)
+            response = json.loads(req.text)
 
             
             # Closing post request after finishing upload
@@ -107,7 +107,7 @@ class ManageFiles():
             return "File Uploaded Successfully", response, True
         except Exception as err:
             response = err
-            return response, False
+            return response, False, False
         
     # This function is to delete the file locally, not from the FMS API (only for cleaning the storage\)
     def delete_file(self, file_key, ext, base_path): 
